- formula
This is a formula object e.g. Y~A+B to describe the
location parameter
- data
This is a data frame in which the variables are recorded
- patid
In a longitudinal context this indexes the individuals.
Note that the observations within each patient is assumed to be ordered
according the timing of the observations.
- start.theta
Optional vector of starting values for location
and nuisance parameters
- modify
We may wish to let the location depend on functions of
the previous outcomes. Since these may be missing, we have to
provide a function that can cope with all the potential values the
outcome may have taken. See paper
- modify.p
This is the dimension of the parameters associated
with the modify function.
- mod.formula
If we require other variables to interact with the
previous observation we must create a set of variables to use. This is
a one-sided formula e.g. ~X+Z, if we wanted to use those variables.
- density.name
This is the density the increment in outcome is
assumed to follow. It can be one of three values: negbin, poisson, geometric.
- link
This is the link function \(g(\mu)=\eta\). Where \(\eta\) is a linear
combination of covariates, and \(\mu\) is the expected value of the
outcome. The link function can be one of four values: identity, log,
logit, hyper.
- iterlim
The maximum number of iterations allowed for the
nlm function.
- gradtol
The parameter gradtol for the nlm
function.
- steptol
The parameter steptol for the nlm function
- na.action
Parameter is not used: If any covariates are missing
the function will return an error.
- print.level
The parameter print.level for the
nlm function. Set to the maximum, verbose level.
- zero.start
It may be the case that it is known that the first
value of the outcome was zero for all individuals, in which case
invoke this TRUE/FALSE option.